<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="83"/>
        <source>Enter the number to configure: </source>
        <translation>Enter the number to configure: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="88"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation>Loading packages...</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 loaded</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation>Initializing...</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="101"/>
        <source>Package Installer</source>
        <translation>Package Installer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="109"/>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="130"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="537"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>Installing other packages... Please open it later.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="541"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>Parsing failed: An illegal file structure was found in the manifest file!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="543"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>Parsing failed: An illegal version number was found in the manifest file!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="545"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>No deb packages found. Please check the folder.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="631"/>
        <source>The deb package may be broken</source>
        <translation>The deb package may be broken</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="639"/>
        <source>You can only install local deb packages</source>
        <translation>You can only install local deb packages</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="653"/>
        <source>Already Added</source>
        <translation>Already Added</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="662"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 does not exist, please reselect</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="330"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="669"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="799"/>
        <source>Bulk Install</source>
        <translation>Bulk Install</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="87"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Installation failed, please check your network connection</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="89"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>Installation failed, please check for updates in Control Center</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="92"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="96"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Installation failed, insufficient disk space</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="113"/>
        <source>No digital signature</source>
        <translation>No digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="632"/>
        <source>Invalid digital signature</source>
        <translation>Invalid digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="124"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="625"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1576"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>The administrator has set policies to prevent installation of this package</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="129"/>
        <source>Installation Failed</source>
        <translation>Installation Failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="634"/>
        <source>Failed to install %1</source>
        <translation>Failed to install %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1617"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1: no valid digital singature</source>
        <translation type="vanished">Failed to install %1: no valid digital singature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="961"/>
        <source>Unable to install - no digital signature</source>
        <translation>Unable to install - no digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="962"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Please go to Control Center to enable developer mode and try again. Proceed?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="965"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1620"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="966"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1621"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Proceed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="919"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1021"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1578"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="923"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1059"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>This package does not have a valid digital signature. Continue with the installation?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1061"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1062"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continue</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="917"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1018"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1575"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1616"/>
        <source>Unable to install</source>
        <translation>Unable to install</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1019"/>
        <source>This package does not have a valid digital signature</source>
        <translation>This package does not have a valid digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="637"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="642"/>
        <source>Broken dependencies: %1</source>
        <translation>Broken dependencies: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="121"/>
        <source>Authentication failed</source>
        <translation>Authentication failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="623"/>
        <source>Unmatched package architecture</source>
        <translation>Unmatched package architecture</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="60"/>
        <source>Drag deb packages here</source>
        <translation>Drag deb packages here</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="102"/>
        <source>Select File</source>
        <translation>Select File</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Collapse</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="171"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Install</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Done</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Back</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="468"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencies in the repository</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="474"/>
        <source>Missing dependencies</source>
        <translation>Missing dependencies</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="523"/>
        <source>Installing dependencies: %1</source>
        <translation>Installing dependencies: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>Earlier version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>Later version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>Unmatched package architecture</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="19"/>
        <source>Select all</source>
        <translation>Select all</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="20"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Install</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="60"/>
        <source>Installing</source>
        <translation>Installing</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="64"/>
        <source>Installed</source>
        <translation>Installed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="72"/>
        <source>Failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="68"/>
        <source>Waiting</source>
        <translation>Waiting</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="231"/>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="234"/>
        <source>Later version installed: %1</source>
        <translation>Later version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="237"/>
        <source>Earlier version installed: %1</source>
        <translation>Earlier version installed: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="160"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Collapse</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Basic</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Check digital signatures if the developer mode is enabled</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="77"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="79"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="707"/>
        <source>Collapse</source>
        <translation>Collapse</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="333"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="966"/>
        <source>Reinstall</source>
        <translation>Reinstall</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="806"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="969"/>
        <source>Later version installed: %1</source>
        <translation>Later version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="808"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="971"/>
        <source>Downgrade</source>
        <translation>Downgrade</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="811"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="974"/>
        <source>Earlier version installed: %1</source>
        <translation>Earlier version installed: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="876"/>
        <source>Installing dependencies: %1</source>
        <translation>Installing dependencies: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1011"/>
        <source>Failed to install %1</source>
        <translation>Failed to install %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="325"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Install</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="329"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Remove</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="337"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="341"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Back</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="345"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Done</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="679"/>
        <source>Installed successfully</source>
        <translation>Installed successfully</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="684"/>
        <source>Uninstalled successfully</source>
        <translation>Uninstalled successfully</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="698"/>
        <source>Uninstall Failed</source>
        <translation>Uninstall Failed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="727"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencies in the repository</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="733"/>
        <source>Missing dependencies</source>
        <translation>Missing dependencies</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="813"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="976"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Update</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1016"/>
        <source>Invalid digital signature</source>
        <translation type="unfinished">Invalid digital signature</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="166"/>
        <source>Name: </source>
        <translation>Name: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="802"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="965"/>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="526"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="551"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="678"/>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Show dependencies</source>
        <translation>Show dependencies</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="576"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="683"/>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>Show related packages</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Collapse</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="112"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Are you sure you want to uninstall %1?
All dependencies will also be removed</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="114"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>Are you sure you want to uninstall %1?
The system or other applications may not work properly</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>Package Installer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Package Installer helps users install and remove local packages, and supports bulk installation.</translation>
    </message>
</context>
</TS>
